@@ -17,9 +17,6 @@ module TextShow.TH.Names (
     fdKeyTypeName,
     uniqueTypeName,
     asInt64ValName,
-#if MIN_VERSION_base(4,6,0)
-    numberTypeName,
-#endif
 #if MIN_VERSION_base(4,8,0)
     giveGCStatsTypeName,
     doCostCentresTypeName,
@@ -30,10 +27,6 @@ module TextShow.TH.Names (
 
 import Language.Haskell.TH.Syntax
 
-#if MIN_VERSION_base(4,7,0)
-import Text.Read.Lex (Number)
-#endif
-
 #if MIN_VERSION_base(4,8,2)
 import GHC.RTS.Flags (GiveGCStats, DoCostCentres, DoHeapProfile, DoTrace)
 #endif
@@ -42,7 +35,11 @@ import GHC.RTS.Flags (GiveGCStats, DoCostCentres, DoHeapProfile, DoTrace)
 
 -- | Creates a 'Name' for a value from the "GHC.Event.Internal" module.
 mkEventName_v :: String -> Name
+#if MIN_VERSION_base(4,15,0)
+mkEventName_v = mkNameG_v "base" "GHC.Event.Internal.Types"
+#else
 mkEventName_v = mkNameG_v "base" "GHC.Event.Internal"
+#endif
 
 -- | The 'Name' of 'evtClose'.
 evtCloseValName :: Name
@@ -68,16 +65,6 @@ asInt64ValName = mkNameG_v "base" "GHC.Event.Unique" "asInt"
 asInt64ValName = mkNameG_v "base" "GHC.Event.Unique" "asInt64"
 #endif
 
-#if MIN_VERSION_base(4,6,0)
--- | The 'Name' of 'Number'.
-numberTypeName :: Name
-# if MIN_VERSION_base(4,7,0)
-numberTypeName = ''Number
-# else
-numberTypeName = mkNameG_tc "base" "Text.Read.Lex" "Number"
-# endif
-#endif
-
 #if MIN_VERSION_base(4,8,0)
 -- | The 'Name' of 'GiveGCStats'.
 giveGCStatsTypeName :: Name
