@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP                        #-}
+{-# LANGUAGE DataKinds                  #-}
 {-# LANGUAGE DeriveDataTypeable         #-}
 {-# LANGUAGE DeriveFoldable             #-}
 {-# LANGUAGE DeriveFunctor              #-}
@@ -7,16 +8,12 @@
 {-# LANGUAGE FlexibleContexts           #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE KindSignatures             #-}
+{-# LANGUAGE PolyKinds                  #-}
 {-# LANGUAGE ScopedTypeVariables        #-}
 {-# LANGUAGE StandaloneDeriving         #-}
 {-# LANGUAGE TemplateHaskell            #-}
 {-# LANGUAGE TypeFamilies               #-}
 
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE DataKinds                  #-}
-{-# LANGUAGE PolyKinds                  #-}
-#endif
-
 #if __GLASGOW_HASKELL__ >= 800
 {-# LANGUAGE DeriveLift                 #-}
 #endif
@@ -46,6 +43,7 @@ module TextShow.FromStringTextShow (
 
 import           Data.Bifunctor.TH (deriveBifunctor, deriveBifoldable,
                                     deriveBitraversable)
+import           Data.Coerce (coerce)
 import           Data.Data (Data, Typeable)
 import           Data.Functor.Classes (Show1(..))
 
@@ -53,9 +51,7 @@ import           Data.Functor.Classes (Show1(..))
 import qualified Generics.Deriving.TH as Generics
 #endif
 
-#if __GLASGOW_HASKELL__ >= 706
 import           GHC.Generics (Generic, Generic1)
-#endif
 
 import           Language.Haskell.TH.Lift
 
@@ -69,7 +65,6 @@ import           TextShow.Classes (TextShow(..), TextShow1(..), TextShow2(..),
                                    showbPrec1, showbPrec2,
                                    showbPrecToShowsPrec, showsPrecToShowbPrec,
                                    showbToShows, showsToShowb)
-import           TextShow.Utils (coerce)
 
 #if defined(NEW_FUNCTOR_CLASSES)
 import           Data.Functor.Classes (Show2(..), showsPrec1, showsPrec2)
@@ -93,10 +88,8 @@ newtype FromStringShow a = FromStringShow { fromStringShow :: a }
            , Eq
            , Foldable
            , Functor
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
            , Generic1
-#endif
 #if __GLASGOW_HASKELL__ >= 800
            , Lift
 #endif
@@ -157,10 +150,8 @@ newtype FromTextShow a = FromTextShow { fromTextShow :: a }
            , Eq
            , Foldable
            , Functor
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
            , Generic1
-#endif
 #if __GLASGOW_HASKELL__ >= 800
            , Lift
 #endif
@@ -219,11 +210,9 @@ instance TextShow1 FromTextShow where
 newtype FromStringShow1 f a = FromStringShow1 { fromStringShow1 :: f a }
   deriving ( Eq
            , Ord
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
-# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+#if defined(__LANGUAGE_DERIVE_GENERIC1__)
            , Generic1
-# endif
 #endif
 #if __GLASGOW_HASKELL__ >= 800
            , Data
@@ -242,12 +231,9 @@ deriving instance Show1       f => Show1       (FromStringShow1 f)
 deriving instance Functor     f => Functor     (FromStringShow1 f)
 deriving instance Foldable    f => Foldable    (FromStringShow1 f)
 deriving instance Traversable f => Traversable (FromStringShow1 f)
-
-# if __GLASGOW_HASKELL__ >= 708
 deriving instance Typeable FromStringShow1
 deriving instance ( Data (f a), Typeable f, Typeable a
                   ) => Data (FromStringShow1 f (a :: *))
-# endif
 #endif
 
 instance Read (f a) => Read (FromStringShow1 f a) where
@@ -300,11 +286,9 @@ instance (Show1 f, Show a) => Show (FromStringShow1 f a) where
 newtype FromTextShow1 f a = FromTextShow1 { fromTextShow1 :: f a }
   deriving ( Eq
            , Ord
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
-# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+#if defined(__LANGUAGE_DERIVE_GENERIC1__)
            , Generic1
-# endif
 #endif
 #if __GLASGOW_HASKELL__ >= 800
            , Data
@@ -321,12 +305,9 @@ deriving instance TextShow1   f => TextShow1   (FromTextShow1 f)
 deriving instance Functor     f => Functor     (FromTextShow1 f)
 deriving instance Foldable    f => Foldable    (FromTextShow1 f)
 deriving instance Traversable f => Traversable (FromTextShow1 f)
-
-# if __GLASGOW_HASKELL__ >= 708
 deriving instance Typeable FromTextShow1
 deriving instance ( Data (f a), Typeable f, Typeable a
                   ) => Data (FromTextShow1 f (a :: *))
-# endif
 #endif
 
 instance Read (f a) => Read (FromTextShow1 f a) where
@@ -384,11 +365,9 @@ instance (TextShow1 f, TextShow a) => TextShow (FromTextShow1 f a) where
 newtype FromStringShow2 f a b = FromStringShow2 { fromStringShow2 :: f a b }
   deriving ( Eq
            , Ord
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
-# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+#if defined(__LANGUAGE_DERIVE_GENERIC1__)
            , Generic1
-# endif
 #endif
 #if __GLASGOW_HASKELL__ >= 800
            , Data
@@ -403,12 +382,9 @@ newtype FromStringShow2 f a b = FromStringShow2 { fromStringShow2 :: f a b }
 deriving instance Functor     (f a) => Functor     (FromStringShow2 f a)
 deriving instance Foldable    (f a) => Foldable    (FromStringShow2 f a)
 deriving instance Traversable (f a) => Traversable (FromStringShow2 f a)
-
-# if __GLASGOW_HASKELL__ >= 708
 deriving instance Typeable FromStringShow2
 deriving instance ( Data (f a b), Typeable f, Typeable a, Typeable b
                   ) => Data (FromStringShow2 f (a :: *) (b :: *))
-# endif
 #endif
 
 instance Read (f a b) => Read (FromStringShow2 f a b) where
@@ -484,11 +460,9 @@ instance (Show2 f, Show a) => Show1 (FromStringShow2 f a) where
 newtype FromTextShow2 f a b = FromTextShow2 { fromTextShow2 :: f a b }
   deriving ( Eq
            , Ord
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
-# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+#if defined(__LANGUAGE_DERIVE_GENERIC1__)
            , Generic1
-# endif
 #endif
 #if __GLASGOW_HASKELL__ >= 800
            , Data
@@ -505,12 +479,9 @@ deriving instance TextShow2    f    => TextShow2   (FromTextShow2 f)
 deriving instance Functor     (f a) => Functor     (FromTextShow2 f a)
 deriving instance Foldable    (f a) => Foldable    (FromTextShow2 f a)
 deriving instance Traversable (f a) => Traversable (FromTextShow2 f a)
-
-# if __GLASGOW_HASKELL__ >= 708
 deriving instance Typeable FromTextShow2
 deriving instance ( Data (f a b), Typeable f, Typeable a, Typeable b
                   ) => Data (FromTextShow2 f (a :: *) (b :: *))
-# endif
 #endif
 
 instance Read (f a b) => Read (FromTextShow2 f a b) where
@@ -613,12 +584,3 @@ $(Generics.deriveRepresentable1 ''FromStringShow2)
 $(Generics.deriveMeta           ''FromTextShow2)
 $(Generics.deriveRepresentable1 ''FromTextShow2)
 #endif
-
-#if __GLASGOW_HASKELL__ < 706
-$(Generics.deriveAll0And1       ''FromStringShow)
-$(Generics.deriveAll0And1       ''FromTextShow)
-$(Generics.deriveRepresentable0 ''FromStringShow1)
-$(Generics.deriveRepresentable0 ''FromStringShow2)
-$(Generics.deriveRepresentable0 ''FromTextShow1)
-$(Generics.deriveRepresentable0 ''FromTextShow2)
-#endif
