@@ -57,9 +57,9 @@ module TextShow.TH.Internal (
     ) where
 
 import           Control.Monad (unless, when)
+import qualified Control.Monad as Monad (fail)
 import           Data.Foldable.Compat
-import           Data.List.Compat
-import qualified Data.List.NonEmpty.Compat as NE (reverse)
+import qualified Data.List.Compat as List
 import           Data.List.NonEmpty.Compat (NonEmpty(..), (<|))
 import qualified Data.Map as Map (fromList, keys, lookup, singleton)
 import           Data.Map (Map)
@@ -78,7 +78,16 @@ import           GHC.Exts ( Char(..), Double(..), Float(..), Int(..), Word(..)
                           , Char#, Double#, Float#, Int#, Word#
 #if MIN_VERSION_base(4,13,0)
                           , Int8#, Int16#, Word8#, Word16#
+# if MIN_VERSION_base(4,16,0)
+                          , Int32#, Word32#
+                          , int8ToInt#, int16ToInt#, int32ToInt#
+                          , intToInt8#, intToInt16#, intToInt32#
+                          , word8ToWord#, word16ToWord#, word32ToWord#
+                          , wordToWord8#, wordToWord16#, wordToWord32#
+# else
                           , extendInt8#, extendInt16#, extendWord8#, extendWord16#
+                          , narrowInt8#, narrowInt16#, narrowWord8#, narrowWord16#
+# endif
 #endif
                           )
 import           GHC.Show (appPrec, appPrec1)
@@ -534,7 +543,7 @@ makeTextShowForCons tsClass tsFun opts instTys cons = do
         splMap     = Map.fromList $ zip lastTyVars spls
 
         makeFun
-          | null cons && emptyCaseBehavior opts && ghc7'8OrLater
+          | null cons && emptyCaseBehavior opts
           = caseE (varE value) []
 
           | null cons
@@ -552,15 +561,8 @@ makeTextShowForCons tsClass tsFun opts instTys cons = do
           , makeFun
           ] ++ map varE spsAndSls
             ++ [varE p, varE value]
-  where
-    ghc7'8OrLater :: Bool
-#if __GLASGOW_HASKELL__ >= 708
-    ghc7'8OrLater = True
-#else
-    ghc7'8OrLater = False
-#endif
 
--- | Generates a lambda expression for howbPrec/liftShowbPrec/etc. for a
+-- | Generates a lambda expression for showbPrec/liftShowbPrec/etc. for a
 -- single constructor.
 makeTextShowForCon :: Name
                    -> TextShowClass
@@ -603,7 +605,7 @@ makeTextShowForCon p tsClass tsFun tvMap
        then do
          let showArgs       = zipWith (makeTextShowForArg 0 tsClass tsFun conName tvMap) argTys' args
              parenCommaArgs = (varE (singletonName tsFun) `appE` charE '(')
-                              : intersperse (varE (singletonName tsFun) `appE` charE ',') showArgs
+                              : List.intersperse (varE (singletonName tsFun) `appE` charE ',') showArgs
              mappendArgs    = foldr' (`infixApp` [| (<>) |])
                                      (varE (singletonName tsFun) `appE` charE ')')
                                      parenCommaArgs
@@ -684,7 +686,7 @@ makeTextShowForCon p tsClass tsFun tvMap
       )
       []
 
--- | Generates a lambda expression for howbPrec/liftShowbPrec/etc. for an
+-- | Generates a lambda expression for showbPrec/liftShowbPrec/etc. for an
 -- argument of a constructor.
 makeTextShowForArg :: Int
                    -> TextShowClass
@@ -728,7 +730,7 @@ makeTextShowForArg p _ tsFun _ _ (ConT tyName) tyExpName =
 makeTextShowForArg p tsClass tsFun conName tvMap ty tyExpName =
     [| $(makeTextShowForType tsClass tsFun conName tvMap False ty) p $(varE tyExpName) |]
 
--- | Generates a lambda expression for howbPrec/liftShowbPrec/etc. for a
+-- | Generates a lambda expression for showbPrec/liftShowbPrec/etc. for a
 -- specific type. The generated expression depends on the number of type variables.
 --
 -- 1. If the type is of kind * (T), apply showbPrec.
@@ -766,9 +768,8 @@ makeTextShowForType tsClass tsFun conName tvMap sl ty = do
         tyVarNames :: [Name]
         tyVarNames = Map.keys tvMap
 
-    itf <- isTyFamily tyCon
-    if any (`mentionsName` tyVarNames) lhsArgs
-          || itf && any (`mentionsName` tyVarNames) tyArgs
+    itf <- isInTypeFamilyApp tyVarNames tyCon tyArgs
+    if any (`mentionsName` tyVarNames) lhsArgs || itf
        then outOfPlaceTyVarError tsClass conName
        else if any (`mentionsName` tyVarNames) rhsArgs
                then appsE $ [ varE $ showPrecOrListName sl (toEnum numLastArgs) tsFun]
@@ -870,7 +871,7 @@ buildTypeInstance tsClass tyConName dataCxt varTysOrig variant = do
         --   instance C (Fam [Char])
         remainingTysOrigSubst :: [Type]
         remainingTysOrigSubst =
-          map (substNamesWithKindStar (union droppedKindVarNames kvNames'))
+          map (substNamesWithKindStar (List.union droppedKindVarNames kvNames'))
             $ take remainingLength varTysOrig
 
         isDataFamily :: Bool
@@ -1009,8 +1010,8 @@ things we can do to make instance contexts that work for 80% of use cases:
 
 -- | Either the given data type doesn't have enough type variables, or one of
 -- the type variables to be eta-reduced cannot realize kind *.
-derivingKindError :: TextShowClass -> Name -> a
-derivingKindError tsClass tyConName = error
+derivingKindError :: TextShowClass -> Name -> Q a
+derivingKindError tsClass tyConName = Monad.fail
     . showString "Cannot derive well-kinded instance of form ‘"
     . showString className
     . showChar ' '
@@ -1029,15 +1030,15 @@ derivingKindError tsClass tyConName = error
 
 -- | One of the last type variables cannot be eta-reduced (see the canEtaReduce
 -- function for the criteria it would have to meet).
-etaReductionError :: Type -> a
-etaReductionError instanceType = error $
+etaReductionError :: Type -> Q a
+etaReductionError instanceType = Monad.fail $
     "Cannot eta-reduce to an instance of form \n\tinstance (...) => "
     ++ pprint instanceType
 
 -- | The data type has a DatatypeContext which mentions one of the eta-reduced
 -- type variables.
-datatypeContextError :: Name -> Type -> a
-datatypeContextError dataName instanceType = error
+datatypeContextError :: Name -> Type -> Q a
+datatypeContextError dataName instanceType = Monad.fail
     . showString "Can't make a derived instance of ‘"
     . showString (pprint instanceType)
     . showString "‘:\n\tData type ‘"
@@ -1047,8 +1048,8 @@ datatypeContextError dataName instanceType = error
 
 -- | The data type mentions one of the n eta-reduced type variables in a place other
 -- than the last nth positions of a data type in a constructor's field.
-outOfPlaceTyVarError :: TextShowClass -> Name -> a
-outOfPlaceTyVarError tsClass conName = error
+outOfPlaceTyVarError :: TextShowClass -> Name -> Q a
+outOfPlaceTyVarError tsClass conName = Monad.fail
     . showString "Constructor ‘"
     . showString (nameBase conName)
     . showString "‘ must only use its last "
@@ -1065,15 +1066,8 @@ outOfPlaceTyVarError tsClass conName = error
 -- Expanding type synonyms
 -------------------------------------------------------------------------------
 
-applySubstitutionKind :: Map Name Kind -> Type -> Type
-#if MIN_VERSION_template_haskell(2,8,0)
-applySubstitutionKind = applySubstitution
-#else
-applySubstitutionKind _ t = t
-#endif
-
 substNameWithKind :: Name -> Kind -> Type -> Type
-substNameWithKind n k = applySubstitutionKind (Map.singleton n k)
+substNameWithKind n k = applySubstitution (Map.singleton n k)
 
 substNamesWithKindStar :: [Name] -> Type -> Type
 substNamesWithKindStar ns t = foldr' (flip substNameWithKind starK) t ns
@@ -1204,9 +1198,7 @@ canRealizeKindStar :: Type -> StarKindStatus
 canRealizeKindStar t
   | hasKindStar t = KindStar
   | otherwise = case t of
-#if MIN_VERSION_template_haskell(2,8,0)
                      SigT _ (VarT k) -> IsKindVar k
-#endif
                      _               -> NotKindStar
 
 -- | Returns 'Just' the kind variable 'Name' of a 'StarKindStatus' if it exists.
@@ -1259,36 +1251,112 @@ primShowTbl = Map.fromList
                     })
 #if MIN_VERSION_base(4,13,0)
     , (''Int8#,   PrimShow
-                    { primShowBoxer      = appE (conE 'I#) . appE (varE 'extendInt8#)
+                    { primShowBoxer      = appE (conE 'I#) . appE (varE int8ToIntHashValName)
                     , primShowPostfixMod = oneHashE
-                    , primShowConv       = mkNarrowE "narrowInt8#"
+                    , primShowConv       = mkNarrowE intToInt8HashValName
                     })
     , (''Int16#,  PrimShow
-                    { primShowBoxer      = appE (conE 'I#) . appE (varE 'extendInt16#)
+                    { primShowBoxer      = appE (conE 'I#) . appE (varE int16ToIntHashValName)
                     , primShowPostfixMod = oneHashE
-                    , primShowConv       = mkNarrowE "narrowInt16#"
+                    , primShowConv       = mkNarrowE intToInt16HashValName
                     })
     , (''Word8#,  PrimShow
-                    { primShowBoxer      = appE (conE 'W#) . appE (varE 'extendWord8#)
+                    { primShowBoxer      = appE (conE 'W#) . appE (varE word8ToWordHashValName)
                     , primShowPostfixMod = twoHashE
-                    , primShowConv       = mkNarrowE "narrowWord8#"
+                    , primShowConv       = mkNarrowE wordToWord8HashValName
                     })
     , (''Word16#, PrimShow
-                    { primShowBoxer      = appE (conE 'W#) . appE (varE 'extendWord16#)
+                    { primShowBoxer      = appE (conE 'W#) . appE (varE word16ToWordHashValName)
                     , primShowPostfixMod = twoHashE
-                    , primShowConv       = mkNarrowE "narrowWord16#"
+                    , primShowConv       = mkNarrowE wordToWord16HashValName
+                    })
+#endif
+#if MIN_VERSION_base(4,16,0)
+    , (''Int32#,  PrimShow
+                    { primShowBoxer      = appE (conE 'I#) . appE (varE 'int32ToInt#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = mkNarrowE 'intToInt32#
+                    })
+    , (''Word32#, PrimShow
+                    { primShowBoxer      = appE (conE 'W#) . appE (varE 'word32ToWord#)
+                    , primShowPostfixMod = twoHashE
+                    , primShowConv       = mkNarrowE 'wordToWord32#
                     })
 #endif
     ]
 
 #if MIN_VERSION_base(4,13,0)
-mkNarrowE :: String -> TextShowFun -> Q Exp -> Q Exp
-mkNarrowE narrowStr tsFun e =
+mkNarrowE :: Name -> TextShowFun -> Q Exp -> Q Exp
+mkNarrowE narrowName tsFun e =
   foldr (`infixApp` [| (<>) |])
         (varE (singletonName tsFun) `appE` charE ')')
-        [ varE (fromStringName tsFun) `appE` stringE ('(':narrowStr ++ " ")
+        [ varE (fromStringName tsFun) `appE` stringE ('(':nameBase narrowName ++ " ")
         , e
         ]
+
+int8ToIntHashValName :: Name
+int8ToIntHashValName =
+# if MIN_VERSION_base(4,16,0)
+  'int8ToInt#
+# else
+  'extendInt8#
+# endif
+
+int16ToIntHashValName :: Name
+int16ToIntHashValName =
+# if MIN_VERSION_base(4,16,0)
+  'int16ToInt#
+# else
+  'extendInt16#
+# endif
+
+intToInt8HashValName :: Name
+intToInt8HashValName =
+# if MIN_VERSION_base(4,16,0)
+  'intToInt8#
+# else
+  'narrowInt8#
+# endif
+
+intToInt16HashValName :: Name
+intToInt16HashValName =
+# if MIN_VERSION_base(4,16,0)
+  'intToInt16#
+# else
+  'narrowInt16#
+# endif
+
+word8ToWordHashValName :: Name
+word8ToWordHashValName =
+# if MIN_VERSION_base(4,16,0)
+  'word8ToWord#
+# else
+  'extendWord8#
+# endif
+
+word16ToWordHashValName :: Name
+word16ToWordHashValName =
+# if MIN_VERSION_base(4,16,0)
+  'word16ToWord#
+# else
+  'extendWord16#
+# endif
+
+wordToWord8HashValName :: Name
+wordToWord8HashValName =
+# if MIN_VERSION_base(4,16,0)
+  'wordToWord8#
+# else
+  'narrowWord8#
+# endif
+
+wordToWord16HashValName :: Name
+wordToWord16HashValName =
+# if MIN_VERSION_base(4,16,0)
+  'wordToWord16#
+# else
+  'narrowWord16#
+# endif
 #endif
 
 oneHashE, twoHashE :: TextShowFun -> Q Exp
@@ -1308,21 +1376,13 @@ charE = litE . charL
 -- | Returns True if a Type has kind *.
 hasKindStar :: Type -> Bool
 hasKindStar VarT{}         = True
-#if MIN_VERSION_template_haskell(2,8,0)
 hasKindStar (SigT _ StarT) = True
-#else
-hasKindStar (SigT _ StarK) = True
-#endif
 hasKindStar _              = False
 
 -- Returns True is a kind is equal to *, or if it is a kind variable.
 isStarOrVar :: Kind -> Bool
-#if MIN_VERSION_template_haskell(2,8,0)
 isStarOrVar StarT  = True
 isStarOrVar VarT{} = True
-#else
-isStarOrVar StarK  = True
-#endif
 isStarOrVar _      = False
 
 -- Generate a list of fresh names with a common prefix, and numbered suffixes.
@@ -1334,7 +1394,7 @@ newNameList prefix n = mapM (newName . (prefix ++) . show) [1..n]
 -- kind variables.
 hasKindVarChain :: Int -> Type -> Maybe [Name]
 hasKindVarChain kindArrows t =
-  let uk = uncurryKind (tyKind t)
+  let uk = uncurryTy (tyKind t)
   in if (length uk - 1 == kindArrows) && all isStarOrVar uk
         then Just (concatMap freeVariables uk)
         else Nothing
@@ -1408,21 +1468,49 @@ isTyVar (VarT _)   = True
 isTyVar (SigT t _) = isTyVar t
 isTyVar _          = False
 
--- | Is the given type a type family constructor (and not a data family constructor)?
-isTyFamily :: Type -> Q Bool
-isTyFamily (ConT n) = do
-    info <- reify n
-    return $ case info of
+-- | Detect if a Name in a list of provided Names occurs as an argument to some
+-- type family. This makes an effort to exclude /oversaturated/ arguments to
+-- type families. For instance, if one declared the following type family:
+--
+-- @
+-- type family F a :: Type -> Type
+-- @
+--
+-- Then in the type @F a b@, we would consider @a@ to be an argument to @F@,
+-- but not @b@.
+isInTypeFamilyApp :: [Name] -> Type -> [Type] -> Q Bool
+isInTypeFamilyApp names tyFun tyArgs =
+  case tyFun of
+    ConT tcName -> go tcName
+    _           -> return False
+  where
+    go :: Name -> Q Bool
+    go tcName = do
+      info <- reify tcName
+      case info of
 #if MIN_VERSION_template_haskell(2,11,0)
-         FamilyI OpenTypeFamilyD{} _       -> True
+        FamilyI (OpenTypeFamilyD (TypeFamilyHead _ bndrs _ _)) _
+          -> withinFirstArgs bndrs
 #else
-         FamilyI (FamilyD TypeFam _ _ _) _ -> True
+        FamilyI (FamilyD TypeFam _ bndrs _) _
+          -> withinFirstArgs bndrs
 #endif
-#if MIN_VERSION_template_haskell(2,9,0)
-         FamilyI ClosedTypeFamilyD{} _     -> True
+
+#if MIN_VERSION_template_haskell(2,11,0)
+        FamilyI (ClosedTypeFamilyD (TypeFamilyHead _ bndrs _ _) _) _
+          -> withinFirstArgs bndrs
+#else
+        FamilyI (ClosedTypeFamilyD _ bndrs _ _) _
+          -> withinFirstArgs bndrs
 #endif
-         _ -> False
-isTyFamily _ = return False
+
+        _ -> return False
+      where
+        withinFirstArgs :: [a] -> Q Bool
+        withinFirstArgs bndrs =
+          let firstArgs = take (length bndrs) tyArgs
+              argFVs    = freeVariables firstArgs
+          in return $ any (`elem` argFVs) names
 
 -- | Are all of the items in a list (which have an ordering) distinct?
 --
@@ -1442,10 +1530,7 @@ mentionsName = go
   where
     go :: Type -> [Name] -> Bool
     go (AppT t1 t2) names = go t1 names || go t2 names
-    go (SigT t _k)  names = go t names
-#if MIN_VERSION_template_haskell(2,8,0)
-                              || go _k names
-#endif
+    go (SigT t k)   names = go t  names || go k  names
     go (VarT n)     names = n `elem` names
     go _            _     = False
 
@@ -1478,13 +1563,16 @@ applyTyCon = applyTy . ConT
 -- [Either, Int, Char]
 -- @
 unapplyTy :: Type -> NonEmpty Type
-unapplyTy = NE.reverse . go
+unapplyTy ty = go ty ty []
   where
-    go :: Type -> NonEmpty Type
-    go (AppT t1 t2)    = t2 <| go t1
-    go (SigT t _)      = go t
-    go (ForallT _ _ t) = go t
-    go t               = t :| []
+    go :: Type -> Type -> [Type] -> NonEmpty Type
+    go _      (AppT ty1 ty2)     args = go ty1 ty1 (ty2:args)
+    go origTy (SigT ty' _)       args = go origTy ty' args
+#if MIN_VERSION_template_haskell(2,11,0)
+    go origTy (InfixT ty1 n ty2) args = go origTy (ConT n `AppT` ty1 `AppT` ty2) args
+    go origTy (ParensT ty')      args = go origTy ty' args
+#endif
+    go origTy _                  args = origTy :| args
 
 -- | Split a type signature by the arrows on its spine. For example, this:
 --
@@ -1503,15 +1591,6 @@ uncurryTy (SigT t _)                 = uncurryTy t
 uncurryTy (ForallT _ _ t)            = uncurryTy t
 uncurryTy t                          = t :| []
 
--- | Like uncurryType, except on a kind level.
-uncurryKind :: Kind -> NonEmpty Kind
-#if MIN_VERSION_template_haskell(2,8,0)
-uncurryKind = uncurryTy
-#else
-uncurryKind (ArrowK k1 k2) = k1 <| uncurryKind k2
-uncurryKind k              = k :| []
-#endif
-
 createKindChain :: Int -> Kind
 createKindChain = go starK
   where
