@@ -1,13 +1,9 @@
 {-# LANGUAGE CPP                        #-}
+{-# LANGUAGE DataKinds                  #-}
 {-# LANGUAGE DeriveGeneric              #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE TemplateHaskell            #-}
 {-# LANGUAGE TypeFamilies               #-}
-
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE DataKinds                  #-}
-#endif
-
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 {-|
@@ -70,17 +66,20 @@ newtype instance TyFamily a b = TyFamily
     )
   deriving ( Arbitrary
            , Show
-#if __GLASGOW_HASKELL__ >= 706
            , Generic
-#endif
            )
 
 -------------------------------------------------------------------------------
 
--- TODO: Replace these with non-orphan instances
+#if !(MIN_VERSION_base(4,9,0))
+-- TODO: Delete this code once we depend on transformers-compat-0.7.1 as the
+-- minimum
+# if !(MIN_VERSION_transformers_compat(0,7,1))
 $(deriveShow1 ''(,,,))
-#if defined(NEW_FUNCTOR_CLASSES)
+#  if defined(NEW_FUNCTOR_CLASSES)
 $(deriveShow2 ''(,,,))
+#  endif
+# endif
 #endif
 
 $(deriveShow1 ''TyCon)
@@ -108,7 +107,3 @@ $(deriveTextShow2 'TyFamily)
 
 $(Generics.deriveMeta           'TyFamily)
 $(Generics.deriveRepresentable1 'TyFamily)
-
-#if __GLASGOW_HASKELL__ < 706
-$(Generics.deriveRepresentable0 'TyFamily)
-#endif
