@@ -1,4 +1,4 @@
-{-# LANGUAGE CPP             #-}
+{-# LANGUAGE CPP                  #-}
 
 #if MIN_VERSION_base(4,8,0)
 {-# LANGUAGE DataKinds            #-}
@@ -7,6 +7,10 @@
 {-# LANGUAGE TypeFamilies         #-}
 {-# LANGUAGE TypeSynonymInstances #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
+# if __GLASGOW_HASKELL__ == 802
+-- See Note [Increased simpl-tick-factor on old GHCs] in TextShow.Data.Complex
+{-# OPTIONS_GHC -fsimpl-tick-factor=200 #-}
+# endif
 #endif
 
 {-|
@@ -36,6 +40,7 @@ import           Language.Haskell.TH.Lib (conT)
 import           Test.QuickCheck (Arbitrary(..))
 import           TextShow.TH.Names
 
+#if !(MIN_VERSION_base(4,15,0))
 $(Generics.deriveAll0 ''RTSFlags)
 $(Generics.deriveAll0 ''GCFlags)
 $(Generics.deriveAll0 ''ConcFlags)
@@ -53,6 +58,11 @@ $(Generics.deriveAll0 giveGCStatsTypeName)
 $(Generics.deriveAll0 doCostCentresTypeName)
 $(Generics.deriveAll0 doHeapProfileTypeName)
 $(Generics.deriveAll0 doTraceTypeName)
+#endif
+
+#if MIN_VERSION_base(4,15,0)
+$(Generics.deriveAll0 ''IoSubSystem)
+#endif
 
 instance Arbitrary RTSFlags where
     arbitrary = genericArbitrary
@@ -63,6 +73,11 @@ instance Arbitrary GCFlags where
 instance Arbitrary ConcFlags where
     arbitrary = genericArbitrary
 
+#if MIN_VERSION_base(4,15,0)
+instance Arbitrary IoSubSystem where
+    arbitrary = genericArbitrary
+#endif
+
 instance Arbitrary MiscFlags where
     arbitrary = genericArbitrary
 
