@@ -13,13 +13,12 @@ module Spec.Data.Functor.SumSpec (main, spec) where
 import Control.Monad.Trans.Instances ()
 
 import Data.Functor.Sum (Sum)
-import Data.Proxy (Proxy(..))
-
-import Instances.Data.Functor.Sum ()
+import Data.Proxy.Compat (Proxy(..))
 
 import Spec.Utils (matchesTextShow1Spec)
 
 import Test.Hspec (Spec, describe, hspec, parallel)
+import Test.QuickCheck.Instances ()
 
 main :: IO ()
 main = hspec spec
